@@ -241,7 +241,7 @@ void ThemeEditorMainWindow::slotOpenTheme()
 bool ThemeEditorMainWindow::loadTheme(const QString &directory)
 {
     if (!directory.isEmpty()) {
-        const QString filename = directory + QDir::separator() + QLatin1String("theme.themerc");
+        const QString filename = directory + QLatin1String("/theme.themerc");
         if (!QFileInfo::exists(filename)) {
             KMessageBox::error(this, i18n("Directory does not contain a theme file. We cannot load theme."));
             return false;
